import once from 'lodash/once';
import * as typeIs from './typeIs';
import createUniqueClassName from './createUniqueClassName';
import getNodeTextContent from './getNodeTextContent';
import { Theme } from './DarkModeProps';
import getTheme from './getTheme';
export { storybookArgTypes } from './storybook/storybookArgTypes';
export { typeIs, createUniqueClassName, getNodeTextContent, getTheme, Theme };
/** Helper type to check if element is a specific React Component  */
export function isComponentType(element, displayName) {
    return (element != null &&
        typeof element === 'object' &&
        'type' in element &&
        element.type.displayName === displayName);
}
/**
 * Utility for making it easier to couple a React Component to a css selector.
 * Useful when writing css selectors that rely on interactivity, i.e. :hover.
 * Example:
 *  const checkBoxWrapper = createDataProp('checkbox-wrapper');
 *  // Used as selector:
 *  css`&:hover ${checkboxWrapper.selector} { }`
 *  // Used on React Component
 *  <div {...checkboxWrapper.prop} />
 * @param {string} name Name of element we want to reference.
 */
export function createDataProp(name) {
    var _a;
    // ts:emit throws an error if this is not typed. Usually this can be inferred.
    var prefix = 'data-leafygreen-ui';
    return {
        prop: (_a = {},
            _a[prefix] = name,
            _a),
        selector: "[".concat(prefix, "=\"").concat(name, "\"]"),
    };
}
/** Object mapping keyCodes to keys */
export var keyMap = {
    ArrowUp: 38,
    ArrowDown: 40,
    ArrowLeft: 37,
    ArrowRight: 39,
    Backspace: 8,
    BracketLeft: 91,
    Delete: 46,
    Enter: 13,
    Escape: 27,
    Space: 32,
    Tab: 9,
};
/**
 * An enum of accepted values for the "aria-current" attribute, used for
 * indicating current/active state across several contexts.
 *
 * The values "false", the empty string, and an ommission of this attribute
 * are all treated identically by user agents and screen readers.
 *
 * W3C Recommendation: https://www.w3.org/TR/wai-aria-1.1/#aria-current
 */
export var AriaCurrentValue = {
    Page: 'page',
    Step: 'step',
    Location: 'location',
    Date: 'date',
    Time: 'time',
    True: 'true',
    Unset: 'false', // equivalent to omitting the aria-current attribute
};
/**
 * Helper function to use the typechecker to catch when
 * not all cases of a type have been handled.
 *
 * Example 1:
 *   let color: 'red' | 'blue' | 'green';
 *   switch (color) {
 *      case 'red':
 *        ...
 *        break;
 *      case 'blue':
 *        ...
 *        break;
 *      default:
 *        enforceExhaustive(color);
 *                          ^^^^^
 *          Argument of type 'string' is not assignable to parameter of type 'never'.
 *   }
 *
 * Example 2:
 *   let key: number | string | symbol;
 *
 *   if (typeof key === 'string') {
 *     ...
 *     return;
 *   }
 *
 *   if (typeof key === 'number') {
 *      ...
 *      return;
 *   }
 *
 *   enforceExhaustive(key);
 *                     ^^^
 *     Argument of type 'symbol' is not assignable to parameter of type 'never'.
 */
export function enforceExhaustive(value) {
    throw Error("Received unhandled value: ".concat(value));
}
export var consoleOnce = {
    error: once(console.error),
    warn: once(console.warn),
    log: once(console.log),
};
